from textual.app import App, ComposeResult, Screen
from textual.widgets import Static, Input, Label, Button, Link, Header
from textual.containers import Container, Horizontal, VerticalScroll, Vertical
from rich.segment import Segment
from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from .main import main
from textual.style import Style
class Screen1(Screen):
    CSS_PATH = "landing.tcss"
    print("hi")
    def compose(self) -> ComposeResult:
        yield Label("Paste the cookie value of _journey_session from your network tap in devtools to start voting via the terminal!", classes="welcome-label")
        yield Input(placeholder="Cookies", id="cookie-input")
    def on_input_submitted(self, event: Input.Submitted) -> None:
        if event.value:
            with open("som-cookie.txt", "w") as f:
                f.write(event.value)
            self.app.push_screen(Screen2())
class Screen2(Screen):
    CSS_PATH = "layout.tcss"
    def compose(self) -> ComposeResult:
        scraper_stuff = main(driver=self.app.driver)
        self.left_project = scraper_stuff[0]
        self.right_project = scraper_stuff[1]
        self.devlog_1 = scraper_stuff[2]
        self.time_1 = scraper_stuff[3]
        self.devlog_2 = scraper_stuff[4]
        self.time_2 = scraper_stuff[5]
        important_buttons = scraper_stuff[6]
        usernames = scraper_stuff[7]
        left_devlogs = scraper_stuff[8]
        left_stuff = scraper_stuff[9]
        right_stuff = scraper_stuff[10]
        right_devlogs = scraper_stuff[11]
        left_description = scraper_stuff[12]
        right_description = scraper_stuff[13]
        self.driver = scraper_stuff[14]
        self.left_button = scraper_stuff[15]
        self.right_button = scraper_stuff[16]
        self.tie_button = scraper_stuff[17]
        self.feedback_form = scraper_stuff[18]
        self.submit_button = scraper_stuff[19]
        for e, button in enumerate(important_buttons):
            if e == 0:
                demo_1 = button.get("href")
            elif e == 1:
                repo_1 = button.get("href")
            elif e == 2:
                demo_2 = button.get("href")
            elif e == 3:
                repo_2 = button.get("href")
        left_devlog_widgets = [
        Static(
            f"[b]{left_stuff[i]}[/b]\n{left_devlogs[i].text.strip()}",
            classes="left-quarter-devlogs"
        )
        for i in range(len(left_devlogs))
    ]

        right_devlog_widgets = [
        Static(
            f"[b]{right_stuff[i].strip()}[/b]\n{right_devlogs[i].text.strip()}".replace("•", ""),
            classes="right-quarter-devlogs"
        )
        for i in range(len(right_devlogs))
    ]
        yield Horizontal(
            VerticalScroll(
                Label(self.left_project, classes="left-quarter"),
                Label("By:" + usernames[0], classes="left-quarter-by"),
                Static(self.devlog_1, classes="left-quarter-devlog-and-time"),
                Static(self.time_1, classes="left-quarter-devlog-and-time"),
                Static(left_description, classes="description"),
                Horizontal(
                    Link(
                        "Go to demo",
                        url=demo_1,
                        tooltip="Click me",
                        classes="left-quarter-demo"
                    ),
                    Link(
                        "Go to repo",
                        url=repo_1,
                        tooltip="Click me",
                        classes="left-quarter-repo"
                    )
                ),
                *left_devlog_widgets,
                classes="whole-devlog"
            ),
            VerticalScroll(
                Label(self.right_project, classes="right-quarter"),
                Label("By:" + usernames[1], classes="right-quarter-by"),
                Static(self.devlog_2, classes="right-quarter-devlog-and-time"),
                Static(self.time_2, classes="right-quarter-devlog-and-time"),
                Static(right_description, classes="description"),
                Horizontal(
                    Link(
                        "Go to demo",
                        url=demo_2,
                        tooltip="Click me",
                        classes="right-quarter-demo"
                    ),
                    Link(
                        "Go to repo",
                        url=repo_2,
                        tooltip="Click me",
                        classes="right-quarter-repo"
                    )
                ),
                *right_devlog_widgets,
                classes="whole-devlog"
            ),
            classes="screen"
        )
        print(self.left_project, self.right_project, self.left_button, self.right_button, self.tie_button)
        yield Input(placeholder="Type the project you want to vote for here:", id="vote-input")
        yield Static("Write your feedback here:", classes="vote-input")
        yield Input(placeholder="Last Name", id="vote-inputs")
    def on_input_submitted(self, event: Input.Submitted) -> None:
        if event.input.id == "vote-input":
            if event.value.lower() == self.left_project.lower():
                self.driver.execute_script("arguments[0].click();", self.left_button)
            elif event.value.lower() == self.right_project.lower():
                self.driver.execute_script("arguments[0].click();", self.right_button)
            elif event.value.lower() == "tie":
                self.driver.execute_script("arguments[0].click();", self.tie_button)
            else:
                print("Invalid project name. Please enter either the left or right project name, or 'tie'.")
        elif event.input.id == "vote-inputs":
            self.feedback_form.send_keys(event.value)
            print("Vote submitted successfully!")
            self.driver.execute_script("arguments[0].click();", self.submit_button)
            Static("Vote submitted successfully!", classes="vote-success")
            if self.app:
                self.app.push_screen(Screen2())
        else:
            print("Please enter your feedback before submitting.")
class Voting(App):
    SCREENS = {"screen_one": Screen1, "screen_two": Screen2}

    def on_mount(self) -> None:
        chrome_options = Options()
        chrome_options.add_experimental_option("detach", True)
        self.driver = webdriver.Chrome(options=chrome_options)
        self.push_screen(Screen1())
if __name__ == "__main__":
    print("Welcome to the SOM CLI Voting App!")
    app = Voting()
    app.run()


import selenium
from selenium import webdriver
from bs4 import BeautifulSoup
from selenium.webdriver.support.ui import WebDriverWait
import requests
from selenium.webdriver.common.by import By
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.support import expected_conditions as EC
def main(driver=None):
    if driver is None:
        chrome_options = Options()
        chrome_options.add_experimental_option("headless", True)
        driver = webdriver.Chrome(options=chrome_options)
    driver.get("https://summer.hackclub.com")
    with open("som-cookie.txt", "r") as f:
        cookie_value = f.read().strip()
    driver.add_cookie({"name": "_journey_session", "value": cookie_value})
    driver.get("https://summer.hackclub.com/votes/new")
    read_stuff = driver.find_elements(By.CSS_SELECTOR, "button.text-nice-blue")
    if read_stuff:
        print(read_stuff)
        for read in read_stuff:
            driver.execute_script("arguments[0].click();", read)
    page_source = driver.page_source
    soup = BeautifulSoup(page_source, 'html.parser')
    print(soup.prettify())
    project_name = soup.find_all("h3", {"class": "text-lg md:text-2xl"})
    left_project = project_name[0].text.strip()
    left_project = left_project.replace("?", "")
    right_project = project_name[1].text.strip()
    right_project = right_project.replace("?", "")
    right_project = right_project.replace("Report ", "")
    right_project = right_project.replace("?", "")
    left_project = left_project.replace("Report ", "")
    if left_project == "Fight for Union" or right_project == "Fight for Union":
        main(driver)
    div_descriptions = soup.find_all("div", {"class": "text-base sm:text-lg text-gray-600"})
    left_div_descr = div_descriptions[0]
    left_description = left_div_descr.find("div").text.strip()
    right_div_descr = div_descriptions[1]
    right_description = right_div_descr.find('div').text.strip()
    button_strip = driver.find_element(By.CSS_SELECTOR, ".flex.flex-col.sm\\:flex-row.justify-center.items-center.space-y-4.sm\\:space-y-0.sm\\:space-x-6.mb-6")
    button_strip = button_strip.find_elements(By.TAG_NAME, "label")
    left_button = button_strip[0].find_element(By.TAG_NAME, "input")
    tie_button = button_strip[1].find_element(By.TAG_NAME, "input")
    right_button = button_strip[2].find_element(By.TAG_NAME, "input")
    form_element = driver.find_element(By.ID, "vote_explanation")
    usernames = []
    usernames = soup.find_all("img", {"class": "w-8 h-8 sm:w-10 sm:h-10 rounded-full mr-2 sm:mr-3"})
    usernames = set([img['alt'] for img in usernames])
    usernames = list(usernames)
    devlogs_and_time = soup.find_all("span", {"class": "text-gray-800"})
    important_buttons = soup.find_all("a", class_="som-button-primary")
    devlog_1 = devlogs_and_time[0].text.strip() + " devlogs"
    time_1 = devlogs_and_time[1].text.strip()
    devlog_2 = devlogs_and_time[2].text.strip() + " devlogs"
    time_2 = devlogs_and_time[3].text.strip()
    devlogs = soup.find_all("div", {"class": "prose max-w-[32em] text-som-dark mb-2 sm:mb-3 text-base sm:text-lg 2xl:text-xl break-words overflow-wrap-anywhere"})
    num_left_devlogs = int(devlog_1.replace(" devlogs", ""))
    num_right_devlogs = int(devlog_2.replace(" devlogs", ""))
    left_devlogs = devlogs[0:num_left_devlogs]
    right_devlogs = devlogs[num_left_devlogs:num_left_devlogs + num_right_devlogs]
    important_stuff = []
    print(left_button, right_button, tie_button)
    wait = WebDriverWait(driver, 10)
    submit_button = wait.until(EC.element_to_be_clickable((By.CSS_SELECTOR, "button.som-button-primary[type='submit'][name='button']")))
    details = soup.find_all("div", {"class": "text-som-detail"})
    for detail in details:
        spans = detail.find_all("span")
        string_construct = ""
        for index in range(0, len(spans), 3):
            cool_string = spans[index:index+3]
            string_construct = " ".join(span.text.strip() for span in cool_string)
            important_stuff.append(string_construct)
    left_stuff = important_stuff[0:num_left_devlogs]
    right_stuff = important_stuff[num_left_devlogs:num_left_devlogs + num_right_devlogs]
    return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button]
